"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mapDispatchToProps = exports.mapStateToProps = exports.SalesReportExpanded = void 0;

var _slingFramework = require("sling-framework");

var _customerJsSdk = require("customer-js-sdk");

require("sling-web-component-table");

require("sling-web-component-card");

require("sling-web-component-button");

require("sling-web-component-loader");

var _slingHelpers = require("sling-helpers");

let instanceName;
const detailcolumns = [{
  title: '',
  field: 'brandId',
  width: '50px',
  type: 'brand_icon'
}, {
  title: '',
  field: 'brandName'
}, {
  title: '',
  field: 'amount',
  type: 'currency',
  align: 'right'
}];
const totalcolumns = [{
  title: 'Saldo Final',
  field: 'name',
  align: 'left',
  width: '80%'
}, {
  title: 'Valor',
  field: 'amount',
  type: 'currency',
  align: 'right'
}];

class SalesReportExpanded extends _slingFramework.SlingBusinessElement {
  constructor() {
    super();
    instanceName = this.localName;
    this.handleGoBackClick = this.handleGoBackClick.bind(this);
    this.showdaterange = false;
    this.gobackbutton = true;
  }

  static get properties() {
    return { ...super.properties,
      startdate: {
        type: String,
        reflectToAttribute: true,
        callSdk: 'required'
      },
      finaldate: {
        type: String,
        reflectToAttribute: true,
        callSdk: 'required'
      },
      producttypeid: {
        type: Number,
        reflectToAttribute: true,
        callSdk: 'required'
      },
      showdaterange: {
        type: Boolean,
        reflectToAttribute: true
      },
      gobackbutton: {
        type: Boolean,
        reflectToAttribute: true
      }
    };
  }

  handleGoBackClick() {
    this.dispatchEventAndMethod('gobackclick');
  }

  getFormattedDateRange() {
    return (0, _slingHelpers.isDateRange)(this.startdate, this.finaldate) ? (0, _slingHelpers.formatDateRange)(this.startdate, this.finaldate) : (0, _slingHelpers.formatDate)(this.startdate);
  }

  renderGoBackButton() {
    return this.gobackbutton ? _slingFramework.html`
    <sling-button
      layout="text"
      size="small"
      onclick="${this.handleGoBackClick}">
      <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24">
        <path d="M15.41 7.41L14 6l-6 6 6 6 1.41-1.41L10.83 12z"/>
        <path d="M0 0h24v24H0z" fill="none"/>
      </svg>
      Voltar
    </sling-button>` : '';
  }

  renderHeader() {
    return this.showdaterange ? _slingFramework.html`
        <div  class="business-component__header business-component__header_primary" slot="header">
          <div>
            <span class="business-component__card-head_title">Resumo das suas vendas</span>
            <span class="business-component__card-head_date">${this.getFormattedDateRange()}</span>
          </div>
          ${this.renderGoBackButton()}
        </div>` : _slingFramework.html`
        <div  class="business-component__header business-component__header_primary" slot="header">
          <div>
            <span class="business-component__card-head_title">Resumo</span>
          </div>
          ${this.renderGoBackButton()}
        </div>
      `;
  }

  static getViewData(apidata = [], productTypeId) {
    return Object.values((0, _slingHelpers.groupByDeep)(apidata.filter(item => item.productTypeId === productTypeId), item => item.brandId)).map(brand => brand.reduce((acc, current) => {
      acc.amount += current.amount;
      return {
        amount: acc.amount,
        brandId: current.brandId,
        brandName: current.brandName,
        productTypeId: current.productTypeId,
        productTypeName: current.productTypeName
      };
    }, {
      amount: 0
    }));
  }

  render() {
    const productTypeId = Number(this.producttypeid);
    const sales = this.constructor.getViewData(this.apidata, productTypeId);
    const {
      productTypeName
    } = sales[0] || {};
    const total = [{
      name: 'Total',
      amount: sales.reduce((acc, sale) => acc + sale.amount, 0)
    }];
    return _slingFramework.html`
      <style>
        .business-component {
  position: relative;
  height: 100%;
}

.business-component__header {
  display: flex;
  flex-flow: row nowrap;
  align-items: center;
}

.business-component__header_primary > sling-button {
  margin-left: auto;
}

.business-component__header_secondary,
.business-component__header_total {
  box-sizing: border-box;
  height: 50px;
  padding: 8px 16px;
  border-top: 1px solid #C3C8D2;
}

.business-component__header_secondary {
  background: rgba(0, 0, 0, 0.02);
}

.business-component__header_total {
  color: #fff;
  background: #242932;
}

.business-component__description {
  font-size: 12px;
  line-height: 18px;
  font-weight: 500;
  letter-spacing: 0.025em;
  white-space: nowrap;
}

.business-component__header_secondary > *:nth-child(1) {
  margin-right: 16px;
}

.business-component__card-head_date {
  display: block;
}

sling-loader[loading] + * {
  opacity: 0.3;
}

:host sling-table {
  border: none;
}

/* for compatibility */

sling-web-sales-report-expanded sling-table {
  border: none;
}

      </style>
      <div class="business-component">
        <sling-loader loading="${this.loading > 0}"></sling-loader>
        <sling-card nopaddingbody nopaddingfooter>
          ${this.renderHeader()}
          <div class="business-component__header business-component__header_secondary">
            <div class="business-component__description">
              ${productTypeName}
            </div>
          </div>
          <sling-table noheader srcdata="${sales}"
            srccolumns="${detailcolumns}"></sling-table>
          <div slot="footer">
            <div class="business-component__header business-component__header_total">
                <div class="business-component__description">
                  Total ${productTypeName}
                </div>
            </div>
            <sling-table noheader srcdata="${total}"
              srccolumns="${totalcolumns}"></sling-table>
          </div>
        </sling-card>
      </div>
    `;
  }

}

exports.SalesReportExpanded = SalesReportExpanded;

const mapStateToProps = state => ({
  apidata: state.salesReducer.salesReport,
  loading: state.globalReducer.loaders[instanceName]
});

exports.mapStateToProps = mapStateToProps;

const mapDispatchToProps = dispatch => ({
  getdata: (0, _customerJsSdk.bindActionCreators)(_customerJsSdk.salesActions.getSalesReportInfo, dispatch)
});

exports.mapDispatchToProps = mapDispatchToProps;